@@ -1,4 +1,6 @@
+# -*- coding: utf-8 -*-
 import itertools
+import math
 
 
 def luhn(value: str) -> bool:
@@ -47,3 +49,23 @@ def fibonacci(n=None):
 
     it = worker()
     return itertools.islice(it, 0, n) if n is not None else it
+
+
+def sieve_of_eratosthenes(n):
+    """
+    Primes less than n.
+    Based on: https://en.wikipedia.org/wiki/Sieve_of_Eratosthenes
+
+    :param int n: n an integer n > 1
+    :rtype: Generator[int]. All prime numbers from 2 through n.
+    """
+
+    sieve = bytearray((0, 0)) + bytearray((1,)) * (n - 2)
+    limit = int(math.sqrt(n) + 1)
+    for p in range(2, limit):
+        if sieve[p]:
+            mulp = p * p
+            size = len(range(mulp, n, p))
+            sieve[mulp:n:p] = bytes(size)
+    prime = (i for i, v in enumerate(sieve) if v)
+    yield from prime
