@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 def string2bool(value, ignorecase=False):
     """
     Function to convert a string representation of
@@ -23,9 +24,9 @@ def string2bool(value, ignorecase=False):
     """
 
     checking = value.lower() if ignorecase else value
-    if checking == 'true':
+    if checking == "true":
         return True
-    elif checking == 'false':
+    elif checking == "false":
         return False
     else:
         raise ValueError
