@@ -1,7 +1,9 @@
+# -*- coding: utf-8 -*-
 """Useful functions for working with strings."""
 import functools
 import html
 import re
+import string
 import urllib.parse
 
 import pymince.algorithm
@@ -14,7 +16,7 @@ _int_regexp_neg = re.compile(r"^-[1-9]\d*\.?[0]*$")
 _bin_regexp_not = re.compile(r"[^01]")
 _percentage_regexp = re.compile(r"^(?:0|[1-9]\d*)(?:\.\d+)?(?:\s)?%$")
 _email_address_regexp = re.compile(r"^\S+@\S+$")
-_roman_regex = re.compile("^M{0,3}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})$")
+_roman_regex = re.compile(r"^M{0,3}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})$")
 
 
 def remove_number_commas(string):
@@ -57,7 +59,34 @@ def replace(value, old_values, new_value, count=-1):
     return value
 
 
-def remove_decimal_zeros(value, decimal_sep='.', min_decimals=None):
+def multireplace(text, replacements):
+    """
+    Given a string and a replacement map, it returns the replaced string.
+
+    :param str text: string to execute replacements on
+    :param Union[dict[str, any], Tuple(str, any)] replacements:
+        2-dict or 2-tuple with value to find and value to replace
+    :rtype: str
+
+     Examples:
+        from pymince.text import multireplace
+
+        mapping = {",": "", "cry": "smile"}
+        multireplace("No, woman, no cry", mapping) # --> "No woman no smile"
+
+    """
+
+    mapping = dict()
+    template = text
+    for i, (word, new_value) in enumerate(dict(replacements).items()):
+        # set valid identifiers to template
+        uid = f"id{i}"
+        template = template.replace(word, f"${uid}")
+        mapping[uid] = new_value
+    return string.Template(template).substitute(**mapping)
+
+
+def remove_decimal_zeros(value, decimal_sep=".", min_decimals=None):
     """
     Removes non-significant decimal zeros from a formatted text number.
 
@@ -70,20 +99,20 @@ def remove_decimal_zeros(value, decimal_sep='.', min_decimals=None):
     """
 
     if not value:
-        return ''
+        return ""
 
     int_part, _, dec_part = value.partition(decimal_sep)
-    int_part = int_part or '0'  # ensure ('.1' => '0.1')
+    int_part = int_part or "0"  # ensure ('.1' => '0.1')
     # remove decimal zeros to the right.
-    dec_part = dec_part.rstrip('0')
+    dec_part = dec_part.rstrip("0")
     dec_part_size = len(dec_part)
     # If the integer part is not 0, it is checked if it is necessary
     # to add decimals to decimal part based on "min_decimals" param
-    if int_part != '0' and min_decimals and dec_part_size < min_decimals:
-        dec_diff = '0' * (min_decimals - dec_part_size)
-        dec_part = f'{dec_part}{dec_diff}'
+    if int_part != "0" and min_decimals and dec_part_size < min_decimals:
+        dec_diff = "0" * (min_decimals - dec_part_size)
+        dec_part = f"{dec_part}{dec_diff}"
 
-    return f'{int_part}{decimal_sep}{dec_part}' if dec_part else int_part
+    return f"{int_part}{decimal_sep}{dec_part}" if dec_part else int_part
 
 
 def is_url(text, schemes=None, hostnames=None):
@@ -137,7 +166,7 @@ def is_int(text):
     "+10",  "+10.",  "+10.0",
     "-10",  "-10.",  "-10.0"
     """
-    return bool(_int_regexp_any.search(text))
+    return _int_regexp_any.fullmatch(text) is not None
 
 
 def is_positive_int(text):
@@ -149,7 +178,7 @@ def is_positive_int(text):
      "10",   "10.",   "10.0",
     "+10",  "+10.",  "+10.0",
     """
-    return bool(_int_regexp_pos.search(text))
+    return _int_regexp_pos.fullmatch(text) is not None
 
 
 def is_negative_int(text):
@@ -161,7 +190,7 @@ def is_negative_int(text):
     "-10",  "-10.",  "-10.0"
     """
 
-    return bool(_int_regexp_neg.search(text))
+    return _int_regexp_neg.fullmatch(text) is not None
 
 
 def is_payment_card(text):
@@ -175,11 +204,11 @@ def is_payment_card(text):
     numb = text.replace(" ", "")
     size = len(numb)
     if 12 <= size <= 19 and pymince.algorithm.luhn(numb):
-        if numb[0] == '4':  # Visa
+        if numb[0] == "4":  # Visa
             isvalid = size in {13, 16, 19}
         elif 51 <= int(numb[:2]) <= 55:  # Mastercard
             isvalid = size == 16
-        elif numb[:2] in {'34', '37'}:  # American Express
+        elif numb[:2] in {"34", "37"}:  # American Express
             isvalid = size == 15
         else:
             isvalid = True
@@ -195,7 +224,7 @@ def is_email_address(text):
     This solution does a very simple check. It only validates that the string contains an at sign (@)
     that is preceded and followed by one or more non whitespace characters.
     """
-    return bool(_email_address_regexp.search(text))
+    return _email_address_regexp.fullmatch(text) is not None
 
 
 def is_percentage(text):
@@ -205,7 +234,7 @@ def is_percentage(text):
     True: "100%", "100 %", "100&nbsp;%", 100.0 %",
     """
     unescaped = html.unescape(text)  # 100&nbsp;% => 100 %
-    return bool(_percentage_regexp.search(unescaped))
+    return _percentage_regexp.fullmatch(unescaped) is not None
 
 
 def is_palindrome(text):
@@ -218,7 +247,7 @@ def is_palindrome(text):
 
 def is_roman(text):
     """Check if the string is a valid roman numeral."""
-    return bool(_roman_regex.search(text))
+    return _roman_regex.fullmatch(text) is not None
 
 
 class fullstr(str):
